from pydantic import BaseModel, model_validator
from pydantic_core import PydanticUndefined


class ConfModel(BaseModel):
    @model_validator(mode="before")
    @classmethod
    def nested_defaults(cls, data):
        for name, field in cls.model_fields.items():
            if name not in data:
                if field.default is PydanticUndefined:
                    data[name] = field.annotation()
                else:
                    data[name] = field.default
        return data


class Total(ConfModel):
    """整体"""
    # 所在页面
    page: str = "init"
    # 是否已展示帮助文档
    is_already_show_doc: bool = False


class UpdatePart(ConfModel):
    """更新代码"""
    # mower-ng 代码分支
    branch: str = "slow"
    # PyPI 仓库镜像
    mirror: str = "aliyun"


class Conf(
    Total,
    UpdatePart,
):
    pass
